@@ -1,10 +1,11 @@
 """Context parser that returns a dictionary from a local yaml file."""
-
-from collections.abc import MutableMapping
+from collections.abc import Mapping
 import logging
+
 import ruamel.yaml as yaml
 
-# use pypyr logger to ensure loglevel is set correctly
+from pypyr.config import config
+
 logger = logging.getLogger(__name__)
 
 
@@ -18,11 +19,11 @@ def get_parsed_context(args):
             "pypyr pipelinename ./myyamlfile.yaml")
     path = ' '.join(args)
     logger.debug("attempting to open file: %s", path)
-    with open(path) as yaml_file:
+    with open(path, encoding=config.default_encoding) as yaml_file:
         yaml_loader = yaml.YAML(typ='safe', pure=True)
         payload = yaml_loader.load(yaml_file)
 
-    if not isinstance(payload, MutableMapping):
+    if not isinstance(payload, Mapping):
         raise TypeError("yaml input should describe a dictionary at the top "
                         "level. You should have something like\n"
                         "key1: value1\n key2: value2\n"
